@@ -372,10 +372,9 @@ impl SourceAnalysis {
         filtered_files: &mut HashSet<PathBuf>,
     ) {
         if let Some(file) = path.to_str() {
-            let skip_cause_test = !config.include_tests() && path.starts_with(root.join("tests"));
             let skip_cause_example = path.starts_with(root.join("examples"))
                 && !config.run_types.contains(&RunType::Examples);
-            if (skip_cause_test || skip_cause_example) || self.is_ignored_module(path) {
+            if skip_cause_example || self.is_ignored_module(path) {
                 let mut analysis = LineAnalysis::new();
                 analysis.ignore_all();
                 self.lines.insert(path.to_path_buf(), analysis);
