@@ -1,8 +1,9 @@
+use crate::config::RunType;
 use crate::source_analysis::Function;
 use serde::{Deserialize, Serialize};
 use std::cmp::{Ord, Ordering};
 use std::collections::btree_map::Iter;
-use std::collections::{BTreeMap, HashMap, HashSet};
+use std::collections::{BTreeMap, BTreeSet, HashMap, HashSet};
 use std::ops::Add;
 use std::path::{Path, PathBuf};
 use tracing::trace;
@@ -56,7 +57,7 @@ impl Add for CoverageStat {
 pub struct Trace {
     /// Line the trace is on in the file
     pub line: u64,
-    /// Optional address showing location in the test artefact
+    /// Optional address showing location in the test artifact
     pub address: HashSet<u64>,
     /// Length of the instruction (useful to get entire condition/branch)
     pub length: usize,
@@ -153,6 +154,17 @@ pub fn coverage_percentage<'a>(traces: impl Iterator<Item = &'a Trace>) -> f64 {
     (amount_covered(t.iter().copied()) as f64) / (amount_coverable(t.iter().copied()) as f64)
 }
 
+#[derive(Debug, Default, PartialEq, Clone, Deserialize, Serialize, Ord, PartialOrd, Eq)]
+pub struct TraceMapSettings {
+    pub packages: BTreeSet<String>,
+    pub workspace: bool,
+    pub excluded_files_raw: BTreeSet<String>,
+    pub included_files_raw: BTreeSet<String>,
+    pub exclude: BTreeSet<String>,
+    pub run_types: BTreeSet<RunType>,
+    pub varargs: BTreeSet<String>,
+}
+
 /// Stores all the program traces mapped to files and provides an interface to
 /// add, query and change traces.
 #[derive(Debug, Default, Deserialize, Serialize)]
@@ -160,6 +172,7 @@ pub struct TraceMap {
     ///rTraces in the program mapped to the given file
     traces: BTreeMap<PathBuf, Vec<Trace>>,
     functions: HashMap<PathBuf, Vec<Function>>,
+    settings: BTreeSet<TraceMapSettings>,
 }
 
 impl TraceMap {
@@ -168,6 +181,20 @@ impl TraceMap {
         Self::default()
     }
 
+    pub fn insert_settings(&mut self, tracemap_settings: TraceMapSettings) {
+        self.settings.insert(tracemap_settings);
+    }
+
+    pub fn append_settings(&mut self, tracemap_settings: Vec<TraceMapSettings>) {
+        let mut settings_collection: BTreeSet<TraceMapSettings> =
+            tracemap_settings.into_iter().collect();
+        self.settings.append(&mut settings_collection);
+    }
+
+    pub fn get_settings(&self) -> &BTreeSet<TraceMapSettings> {
+        &self.settings
+    }
+
     pub fn set_functions(&mut self, functions: HashMap<PathBuf, Vec<Function>>) {
         self.functions = functions;
     }
